#!/bin/sh
set -e

cd $(realpath $(dirname "${0}"))/basic

# Configure APK repository
echo "@vm https://dl.dasm.cz/spotter-abuild" >>/etc/apk/repositories
cp etc/apk/keys/repokey.rsa.pub /etc/apk/keys/repokey.rsa.pub

# Install packages
apk --no-cache add ca-certificates curl bridge e2fsprogs-extra gettext iptables kbd-misc libcap libressl libseccomp postfix python3 py3-bcrypt py3-cffi py3-cryptography py3-dnspython py3-jinja2 py3-requests py3-six py3-werkzeug nginx util-linux acme-sh@vm lxc@vm

# Copy boot configuration
cp boot/extlinux.conf /boot/extlinux.conf
cp boot/vm.txt /boot/vm.txt
cp etc/inittab /etc/inittab
cp sbin/extend-disk /sbin/extend-disk
cp sbin/vmtty /sbin/vmtty
>/etc/motd

# Enable support for Czech characters
cp etc/rc.conf /etc/rc.conf
cp etc/conf.d/consolefont /etc/conf.d/consolefont

# Configure NTP client
cp etc/conf.d/ntpd /etc/conf.d/ntpd

# Configure networking
cp etc/conf.d/iptables /etc/conf.d/iptables
cp etc/iptables/rules-save /etc/iptables/rules-save
cp etc/network/interfaces /etc/network/interfaces
service networking restart

# Configure LXC
mkdir /var/log/lxc
echo -e "172.17.0.1 host" >>/etc/hosts

# Copy VMMgr resources
cp etc/init.d/vmmgr /etc/init.d/vmmgr
rc-update -u
cp -r srv/vm /srv/vm
ln -s /srv/vm/cli.py /usr/bin/vmmgr

# Configure nginx and create a self-signed certificate
cp etc/nginx/nginx.conf /etc/nginx/nginx.conf
vmmgr install

# Configure postfix
cp etc/postfix/main.cf /etc/postfix/main.cf 
newaliases

# Configure services
for SERVICE in cgroups consolefont crond iptables nginx ntpd postfix swap vmmgr; do
    rc-update add ${SERVICE} boot
    service ${SERVICE} start
done
